﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using MvcApplication1.Models;

namespace MvcApplication1.Controllers
{
    public class AdminController : Controller
    {
        private FlowersDBEntities db = new FlowersDBEntities();

        //
        // GET: /Admin/

        [Authorize(Roles = "Administrators")]
        public ActionResult Index()
        {
            var flowers = (from flower in db.Flowers select flower).ToList();
            return View(flowers);
        }

        //
        // GET: /Admin/Details/5

        [Authorize(Roles = "Administrators")]
        public ActionResult Details(int id)
        {
            var flowerDetails = (from flower in db.Flowers
                                 where flower.FlowerId == id
                                 select flower).First();
            return View(flowerDetails);
        }

        //
        // GET: /Admin/Create

        [Authorize(Roles = "Administrators")]
        public ActionResult Create()
        {
            Flower flower = new Flower();
            return View(flower);
        }

        //
        // POST: /Admin/Create

        [HttpPost]
        [Authorize(Roles = "Administrators")]
        public ActionResult Create(Flower flower)
        {
            try
            {
                if (ModelState.IsValid)
                {
                    db.AddToFlowers(flower);
                    db.SaveChanges();
                    return RedirectToAction("Index");
                }
            }
            catch (Exception ex)
            {
                ModelState.AddModelError(String.Empty, ex);
            }
            return View(flower);
        }

        //
        // GET: /Admin/Edit/5

        [Authorize(Roles = "Administrators")]
        public ActionResult Edit(int id)
        {
            var flowerEdit = (from flower in db.Flowers
                                 where flower.FlowerId == id
                                 select flower).First();
            return View(flowerEdit);
        }

        //
        // POST: /Admin/Edit/5

        [HttpPost]
        [Authorize(Roles = "Administrators")]
        public ActionResult Edit(int id, FormCollection collection)
        {
            var flowerEdit = (from flower in db.Flowers
                              where flower.FlowerId == id
                              select flower).First();
            try
            {
                UpdateModel(flowerEdit);
                db.SaveChanges();

                return RedirectToAction("Index");
            }
            catch
            {
                return View(flowerEdit);
            }
        }

        //
        // GET: /Admin/Delete/5

        [Authorize(Roles = "Administrators")]
        public ActionResult Delete(int id)
        {
            var flowerDelete = (from flower in db.Flowers
                              where flower.FlowerId == id
                              select flower).First();
            return View(flowerDelete);
        }

        //
        // POST: /Admin/Delete/5

        [HttpPost]
        [Authorize(Roles = "Administrators")]
        public ActionResult Delete(int id, FormCollection collection)
        {
            var flowerDelete = (from flower in db.Flowers
                                where flower.FlowerId == id
                                select flower).First();
            try
            {
                db.DeleteObject(flowerDelete);
                db.SaveChanges();

                return RedirectToAction("Index");
            }
            catch
            {
                return View(flowerDelete);
            }
        }
    }
}
